/*
 * Copyright (c) 1998 Vectaport Inc.
 *
 * Permission to use, copy, modify, distribute, and sell this software and
 * its documentation for any purpose is hereby granted without fee, provided
 * that the above copyright notice appear in all copies and that both that
 * copyright notice and this permission notice appear in supporting
 * documentation, and that the names of the copyright holders not be used in
 * advertising or publicity pertaining to distribution of the software
 * without specific, written prior permission.  The copyright holders make
 * no representations about the suitability of this software for any purpose.
 * It is provided "as is" without express or implied warranty.
 *
 * THE COPYRIGHT HOLDERS DISCLAIM ALL WARRANTIES WITH REGARD TO THIS
 * SOFTWARE, INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDERS BE LIABLE FOR ANY SPECIAL,
 * INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING
 * FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT,
 * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION
 * WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 *
 */

#include <MapServ/mapfunc.h>
#include <ComTerp/comterpserv.h>
#include <ProjServ/projfunc.h>
#include <ProjServ/projhandler.h>

ProjservHandler::ProjservHandler(void) : ComterpHandler() {
  AddCommands(comterp_);
}


void ProjservHandler::AddCommands(ComTerp* comterp) {

    static int pointfeature_symid = symbol_add("pointfeature");
    ComValue* testval = comterp->localvalue(pointfeature_symid);
    if (testval && testval->is_command()) return;

    comterp->add_command("pointfeature", new PointFeatureFunc(comterp));
    comterp->add_command("linefeature", new LineFeatureFunc(comterp));
    comterp->add_command("areafeature", new AreaFeatureFunc(comterp));
    comterp->add_command("nodefeature", new NodeFeatureFunc(comterp));
    comterp->add_command("polygonarea", new PolygonAreaFunc(comterp));
    comterp->add_command("featureclass", new FeatureClassFunc(comterp));
    comterp->add_command("addfeature", new AddFeatureFunc(comterp));
    comterp->add_command("pointdistance", new PointDistanceFunc(comterp));
    comterp->add_command("nearestpointinline", new NearestPointInLineFunc(comterp));

    comterp->add_command("numfeatures", new NumFeaturesFunc(comterp));
    comterp->add_command("getfeature", new GetFeatureFunc(comterp));

    comterp->add_command("attrsel", new AttrSelFunc(comterp));
    comterp->add_command("shapesel", new ShapeSelFunc(comterp));
    comterp->add_command("exprfc", new ExprFCFunc(comterp));

    comterp->add_command("extentfc", new FclassExtentFunc(comterp));
#if defined(CLIPPOLY)
    comterp->add_command("cliprect", new ClipRectFunc(comterp));
    comterp->add_command("clippolyaminb", new ClipPolyAminBFunc(comterp));
    comterp->add_command("clippolybmina", new ClipPolyBminAFunc(comterp));
    comterp->add_command("clippolyaandb", new ClipPolyAandBFunc(comterp));
#endif

    comterp->add_command("importfc", new ImportFCFunc(comterp));
    comterp->add_command("exportfc", new ExportFCFunc(comterp));
    comterp->add_command("printfc", new PrintFCFunc(comterp));

    comterp->add_command("paintfc", new PaintFCFunc(comterp));
    comterp->add_command("painttbl", new PaintFCTblFunc(comterp));

    ExportFCGrFunc* expgraphic_func = new ExportFCGrFunc(comterp);
    comterp->add_command("exportgr", expgraphic_func);
    comterp->add_command("exportgrgs", new ExportFCGrGsFunc(expgraphic_func));
    comterp->add_command("exportgrtr", new ExportFCGrTrFunc(expgraphic_func));
    comterp->add_command("printgr", new PrintFCGrFunc(comterp));

    comterp->add_command("loadvpffc", new LoadVpfFCFunc(comterp));
    comterp->add_command("graticulefc", new GraticuleFCFunc(comterp));

}

